Computations
============


Algorithms
----------

.. automodule:: reikna.algorithms


Linear algebra
--------------

.. automodule:: reikna.linalg


Fast Fourier transform and related utilities
--------------------------------------------

.. automodule:: reikna.fft


Discrete harmonic transform
---------------------------

.. currentmodule:: reikna.dht
.. autofunction :: reikna.dht.get_spatial_grid
.. autofunction :: reikna.dht.harmonic
.. autoclass :: reikna.dht.DHT


Counter-based random number generators
--------------------------------------

.. automodule:: reikna.cbrng
